from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.rtc_info_rtc_ice_server_protocol import RtcInfoRtcIceServerProtocol
from ..models.rtc_info_rtc_ice_transport_policies_item import RtcInfoRtcIceTransportPoliciesItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="RtcInfo")


@attr.s(auto_attribs=True)
class RtcInfo:
    """
    Attributes:
        rtc_ice_transport_policies (Union[Unset, List[RtcInfoRtcIceTransportPoliciesItem]]):
        rtc_ice_server_protocol (Union[Unset, RtcInfoRtcIceServerProtocol]):
        use_all_servers (Union[Unset, bool]):
    """

    rtc_ice_transport_policies: Union[Unset, List[RtcInfoRtcIceTransportPoliciesItem]] = UNSET
    rtc_ice_server_protocol: Union[Unset, RtcInfoRtcIceServerProtocol] = UNSET
    use_all_servers: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        rtc_ice_transport_policies: Union[Unset, List[str]] = UNSET
        if not isinstance(self.rtc_ice_transport_policies, Unset):
            rtc_ice_transport_policies = []
            for rtc_ice_transport_policies_item_data in self.rtc_ice_transport_policies:
                rtc_ice_transport_policies_item = rtc_ice_transport_policies_item_data.value

                rtc_ice_transport_policies.append(rtc_ice_transport_policies_item)

        rtc_ice_server_protocol: Union[Unset, str] = UNSET
        if not isinstance(self.rtc_ice_server_protocol, Unset):
            rtc_ice_server_protocol = self.rtc_ice_server_protocol.value

        use_all_servers = self.use_all_servers

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if rtc_ice_transport_policies is not UNSET:
            field_dict["rtcIceTransportPolicies"] = rtc_ice_transport_policies
        if rtc_ice_server_protocol is not UNSET:
            field_dict["rtcIceServerProtocol"] = rtc_ice_server_protocol
        if use_all_servers is not UNSET:
            field_dict["useAllServers"] = use_all_servers

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        rtc_ice_transport_policies = []
        _rtc_ice_transport_policies = d.pop("rtcIceTransportPolicies", UNSET)
        for rtc_ice_transport_policies_item_data in _rtc_ice_transport_policies or []:
            rtc_ice_transport_policies_item = RtcInfoRtcIceTransportPoliciesItem(rtc_ice_transport_policies_item_data)

            rtc_ice_transport_policies.append(rtc_ice_transport_policies_item)

        _rtc_ice_server_protocol = d.pop("rtcIceServerProtocol", UNSET)
        rtc_ice_server_protocol: Union[Unset, RtcInfoRtcIceServerProtocol]
        if isinstance(_rtc_ice_server_protocol, Unset):
            rtc_ice_server_protocol = UNSET
        else:
            rtc_ice_server_protocol = RtcInfoRtcIceServerProtocol(_rtc_ice_server_protocol)

        use_all_servers = d.pop("useAllServers", UNSET)

        rtc_info = cls(
            rtc_ice_transport_policies=rtc_ice_transport_policies,
            rtc_ice_server_protocol=rtc_ice_server_protocol,
            use_all_servers=use_all_servers,
        )

        rtc_info.additional_properties = d
        return rtc_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.camera import Camera


T = TypeVar("T", bound="LocalizationViewConfiguration")


@attr.s(auto_attribs=True)
class LocalizationViewConfiguration:
    """
    Attributes:
        camera (Union[Unset, Camera]):
    """

    camera: Union[Unset, "Camera"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        camera: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.camera, Unset):
            camera = self.camera.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if camera is not UNSET:
            field_dict["camera"] = camera

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.camera import Camera

        d = src_dict.copy()
        _camera = d.pop("camera", UNSET)
        camera: Union[Unset, Camera]
        if isinstance(_camera, Unset):
            camera = UNSET
        else:
            camera = Camera.from_dict(_camera)

        localization_view_configuration = cls(
            camera=camera,
        )

        localization_view_configuration.additional_properties = d
        return localization_view_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_query_api_client.models import UuidListResponse
from formant.sdk.cloud.v2.formant_query_api_client.api.online_devices import online_devices_controller_online
from formant.sdk.cloud.v2.formant_query_api_client.types import *




from typing import Callable, Union, Any
from formant.sdk.cloud.v2.formant_admin_api_client import Client, AuthenticatedClient

class Resources():

    def __init__(self, get_client: Callable[([None], Union[(Any, Client, AuthenticatedClient)])]):
        self._get_client = get_client



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="OverviewSettings")


@attr.s(auto_attribs=True)
class OverviewSettings:
    """
    Attributes:
        overview_show_sidebar (Union[Unset, bool]):
        overview_sidebar_closed (Union[Unset, bool]):
        overview_settings_enabled (Union[Unset, bool]):
        overview_primary_mode (Union[Unset, None, str]):
        overview_secondary_mode (Union[Unset, None, str]):
        overview_show_filters (Union[Unset, bool]):
    """

    overview_show_sidebar: Union[Unset, bool] = UNSET
    overview_sidebar_closed: Union[Unset, bool] = UNSET
    overview_settings_enabled: Union[Unset, bool] = UNSET
    overview_primary_mode: Union[Unset, None, str] = UNSET
    overview_secondary_mode: Union[Unset, None, str] = UNSET
    overview_show_filters: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        overview_show_sidebar = self.overview_show_sidebar
        overview_sidebar_closed = self.overview_sidebar_closed
        overview_settings_enabled = self.overview_settings_enabled
        overview_primary_mode = self.overview_primary_mode
        overview_secondary_mode = self.overview_secondary_mode
        overview_show_filters = self.overview_show_filters

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if overview_show_sidebar is not UNSET:
            field_dict["overviewShowSidebar"] = overview_show_sidebar
        if overview_sidebar_closed is not UNSET:
            field_dict["overviewSidebarClosed"] = overview_sidebar_closed
        if overview_settings_enabled is not UNSET:
            field_dict["overviewSettingsEnabled"] = overview_settings_enabled
        if overview_primary_mode is not UNSET:
            field_dict["overviewPrimaryMode"] = overview_primary_mode
        if overview_secondary_mode is not UNSET:
            field_dict["overviewSecondaryMode"] = overview_secondary_mode
        if overview_show_filters is not UNSET:
            field_dict["overviewShowFilters"] = overview_show_filters

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        overview_show_sidebar = d.pop("overviewShowSidebar", UNSET)

        overview_sidebar_closed = d.pop("overviewSidebarClosed", UNSET)

        overview_settings_enabled = d.pop("overviewSettingsEnabled", UNSET)

        overview_primary_mode = d.pop("overviewPrimaryMode", UNSET)

        overview_secondary_mode = d.pop("overviewSecondaryMode", UNSET)

        overview_show_filters = d.pop("overviewShowFilters", UNSET)

        overview_settings = cls(
            overview_show_sidebar=overview_show_sidebar,
            overview_sidebar_closed=overview_sidebar_closed,
            overview_settings_enabled=overview_settings_enabled,
            overview_primary_mode=overview_primary_mode,
            overview_secondary_mode=overview_secondary_mode,
            overview_show_filters=overview_show_filters,
        )

        overview_settings.additional_properties = d
        return overview_settings

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.src.resources.resources import Resources
from formant.sdk.cloud.v2.formant_query_api_client.api.metadata import metadata_controller_list_metadata, metadata_controller_list_stream_names, metadata_controller_list_device_ids
from formant.sdk.cloud.v2.formant_query_api_client.models.scope_filter import ScopeFilter

class Metadata(Resources):

    def list_metadata(self, scope_filer: ScopeFilter):
        'List stream metadata'
        client = self._get_client()
        response = metadata_controller_list_metadata.sync_detailed(client=client, json_body=scope_filer)
        return response

    async def list_metadata_async(self, scope_filer: ScopeFilter):
        'List stream metadata'
        client = self._get_client()
        response = (await metadata_controller_list_metadata.asyncio_detailed(client=client, json_body=scope_filer))
        return response

    def list_stream_names(self, scope_filer: ScopeFilter):
        'List stream names'
        client = self._get_client()
        response = metadata_controller_list_stream_names.sync_detailed(client=client, json_body=scope_filer)
        return response

    async def list_stream_names_async(self, scope_filer: ScopeFilter):
        'List stream names'
        client = self._get_client()
        response = (await metadata_controller_list_stream_names.asyncio_detailed(client=client, json_body=scope_filer))
        return response

    def list_device_ids(self, scope_filer: ScopeFilter):
        'List device ids'
        client = self._get_client()
        response = metadata_controller_list_device_ids.sync_detailed(client=client, json_body=scope_filer)
        return response

    async def list_device_ids_async(self, scope_filer: ScopeFilter):
        'List device ids'
        client = self._get_client()
        response = (await metadata_controller_list_device_ids.asyncio_detailed(client=client, json_body=scope_filer))
        return response



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="SeekResult")


@attr.s(auto_attribs=True)
class SeekResult:
    """
    Attributes:
        time (Union[Unset, datetime.datetime]):
    """

    time: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        time: Union[Unset, str] = UNSET
        if not isinstance(self.time, Unset):
            time = self.time.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if time is not UNSET:
            field_dict["time"] = time

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _time = d.pop("time", UNSET)
        time: Union[Unset, datetime.datetime]
        if isinstance(_time, Unset):
            time = UNSET
        else:
            time = isoparse(_time)

        seek_result = cls(
            time=time,
        )

        seek_result.additional_properties = d
        return seek_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/event.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bprotos/model/v1/event.proto\x12\x08v1.model\"\xc0\x02\n\x05\x45vent\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x15\n\rend_timestamp\x18\x08 \x01(\x03\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x13\n\x0bstream_type\x18\x04 \x01(\t\x12\x1c\n\x14notification_enabled\x18\x05 \x01(\x08\x12$\n\x08severity\x18\t \x01(\x0e\x32\x12.v1.model.Severity\x12\n\n\x02id\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x18\n\x10\x65vent_trigger_id\x18\x0c \x01(\t\x12\'\n\x04tags\x18\x06 \x03(\x0b\x32\x19.v1.model.Event.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"\xa2\x01\n\x17\x41gentEventConfiguration\x12\x33\n\x0e\x65vent_triggers\x18\x01 \x03(\x0b\x32\x1b.v1.model.AgentEventTrigger\x12<\n\x17stateful_event_triggers\x18\x03 \x03(\x0b\x32\x1b.v1.model.AgentEventTrigger\x12\x14\n\x0clast_updated\x18\x02 \x01(\x03\"\xd6\x02\n\x11\x41gentEventTrigger\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\x03\x12&\n\tcondition\x18\x04 \x01(\x0b\x32\x13.v1.model.Condition\x12*\n\rexitCondition\x18\x05 \x01(\x0b\x32\x13.v1.model.Condition\x12\x19\n\x11isStatefulTrigger\x18\x06 \x01(\x08\x12L\n\x1cstatefulTriggerConfiguration\x18\x07 \x01(\x0b\x32&.v1.model.StatefulTriggerConfiguration\x12\x0f\n\x07message\x18\x08 \x01(\t\x12\x15\n\rmessageFormat\x18\x0b \x01(\t\x12\x10\n\x08severity\x18\t \x01(\t\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\"\x85\x04\n\tCondition\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12;\n\x08presence\x18\x02 \x01(\x0b\x32\'.v1.model.PresenceEventTriggerConditionH\x00\x12=\n\tthreshold\x18\x03 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerConditionH\x00\x12\x35\n\x05regex\x18\x04 \x01(\x0b\x32$.v1.model.RegexEventTriggerConditionH\x00\x12\x37\n\x06\x62itset\x18\x05 \x01(\x0b\x32%.v1.model.BitsetEventTriggerConditionH\x00\x12\x39\n\x07\x62\x61ttery\x18\x06 \x01(\x0b\x32&.v1.model.BatteryEventTriggerConditionH\x00\x12<\n\x07numeric\x18\x07 \x01(\x0b\x32).v1.model.NumericSetEventTriggerConditionH\x00\x12\x33\n\x04json\x18\x08 \x01(\x0b\x32#.v1.model.JsonEventTriggerConditionH\x00\x12\x41\n\x0b\x61utoresolve\x18\t \x01(\x0b\x32*.v1.model.AutoresolveEventTriggerConditionH\x00\x42\x0b\n\tcondition\"\x1f\n\x1dPresenceEventTriggerCondition\"\"\n AutoresolveEventTriggerCondition\"^\n\x1eThresholdEventTriggerCondition\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ThresholdOperator\"^\n\x10NumericCondition\x12\r\n\x05label\x18\x01 \x01(\t\x12;\n\tcondition\x18\x02 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerCondition\"\x80\x01\n\x1fNumericSetEventTriggerCondition\x12.\n\nconditions\x18\x01 \x03(\x0b\x32\x1a.v1.model.NumericCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"\xa5\x01\n\x10\x42\x61tteryCondition\x12%\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x16.v1.model.BatteryField\x12;\n\tcondition\x18\x02 \x01(\x0b\x32(.v1.model.ThresholdEventTriggerCondition\x12-\n\x08operator\x18\x03 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"}\n\x1c\x42\x61tteryEventTriggerCondition\x12.\n\nconditions\x18\x01 \x03(\x0b\x32\x1a.v1.model.BatteryCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\"+\n\x1aRegexEventTriggerCondition\x12\r\n\x05value\x18\x01 \x01(\t\"\x7f\n\x1b\x42itsetEventTriggerCondition\x12\x31\n\x0e\x62it_conditions\x18\x01 \x03(\x0b\x32\x19.v1.model.BitsetCondition\x12-\n\x08operator\x18\x02 \x01(\x0e\x32\x1b.v1.model.ConditionOperator\";\n\x0f\x42itsetCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04true\x18\x02 \x01(\x08\x12\r\n\x05\x66\x61lse\x18\x03 \x01(\x08\",\n\x19JsonEventTriggerCondition\x12\x0f\n\x07jqQuery\x18\x01 \x01(\t\"W\n\x1cStatefulTriggerConfiguration\x12\x1b\n\x13\x65mitOnEnteringState\x18\x01 \x01(\x08\x12\x1a\n\x12\x65mitOnLeavingState\x18\x02 \x01(\x08*:\n\x08Severity\x12\x08\n\x04INFO\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0c\n\x08\x43RITICAL\x10\x03*D\n\x0c\x42\x61tteryField\x12\n\n\x06\x43harge\x10\x00\x12\x0b\n\x07\x43urrent\x10\x01\x12\x0e\n\nPercentage\x10\x02\x12\x0b\n\x07Voltage\x10\x03*F\n\x11ThresholdOperator\x12\x06\n\x02LT\x10\x00\x12\x07\n\x03LTE\x10\x01\x12\x06\n\x02GT\x10\x02\x12\x07\n\x03GTE\x10\x03\x12\x06\n\x02\x45Q\x10\x04\x12\x07\n\x03NEQ\x10\x05*%\n\x11\x43onditionOperator\x12\x07\n\x03\x41NY\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
)

_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='v1.model.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INFO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2451,
  serialized_end=2509,
)
_sym_db.RegisterEnumDescriptor(_SEVERITY)

Severity = enum_type_wrapper.EnumTypeWrapper(_SEVERITY)
_BATTERYFIELD = _descriptor.EnumDescriptor(
  name='BatteryField',
  full_name='v1.model.BatteryField',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Charge', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Current', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Percentage', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Voltage', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2511,
  serialized_end=2579,
)
_sym_db.RegisterEnumDescriptor(_BATTERYFIELD)

BatteryField = enum_type_wrapper.EnumTypeWrapper(_BATTERYFIELD)
_THRESHOLDOPERATOR = _descriptor.EnumDescriptor(
  name='ThresholdOperator',
  full_name='v1.model.ThresholdOperator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GTE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQ', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEQ', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2581,
  serialized_end=2651,
)
_sym_db.RegisterEnumDescriptor(_THRESHOLDOPERATOR)

ThresholdOperator = enum_type_wrapper.EnumTypeWrapper(_THRESHOLDOPERATOR)
_CONDITIONOPERATOR = _descriptor.EnumDescriptor(
  name='ConditionOperator',
  full_name='v1.model.ConditionOperator',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ANY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2653,
  serialized_end=2690,
)
_sym_db.RegisterEnumDescriptor(_CONDITIONOPERATOR)

ConditionOperator = enum_type_wrapper.EnumTypeWrapper(_CONDITIONOPERATOR)
INFO = 0
WARNING = 1
ERROR = 2
CRITICAL = 3
Charge = 0
Current = 1
Percentage = 2
Voltage = 3
LT = 0
LTE = 1
GT = 2
GTE = 3
EQ = 4
NEQ = 5
ANY = 0
ALL = 1



_EVENT_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='v1.model.Event.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.Event.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.Event.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=356,
)

_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='v1.model.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.Event.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_timestamp', full_name='v1.model.Event.end_timestamp', index=1,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='v1.model.Event.message', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_name', full_name='v1.model.Event.stream_name', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_type', full_name='v1.model.Event.stream_type', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_enabled', full_name='v1.model.Event.notification_enabled', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='v1.model.Event.severity', index=6,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.Event.id', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='v1.model.Event.type', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_trigger_id', full_name='v1.model.Event.event_trigger_id', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='v1.model.Event.tags', index=10,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVENT_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=362,
)


_AGENTEVENTCONFIGURATION = _descriptor.Descriptor(
  name='AgentEventConfiguration',
  full_name='v1.model.AgentEventConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_triggers', full_name='v1.model.AgentEventConfiguration.event_triggers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stateful_event_triggers', full_name='v1.model.AgentEventConfiguration.stateful_event_triggers', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_updated', full_name='v1.model.AgentEventConfiguration.last_updated', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=527,
)


_AGENTEVENTTRIGGER = _descriptor.Descriptor(
  name='AgentEventTrigger',
  full_name='v1.model.AgentEventTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='v1.model.AgentEventTrigger.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='v1.model.AgentEventTrigger.stream', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='v1.model.AgentEventTrigger.interval', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='v1.model.AgentEventTrigger.condition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exitCondition', full_name='v1.model.AgentEventTrigger.exitCondition', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isStatefulTrigger', full_name='v1.model.AgentEventTrigger.isStatefulTrigger', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statefulTriggerConfiguration', full_name='v1.model.AgentEventTrigger.statefulTriggerConfiguration', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='v1.model.AgentEventTrigger.message', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageFormat', full_name='v1.model.AgentEventTrigger.messageFormat', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='v1.model.AgentEventTrigger.severity', index=9,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification_enabled', full_name='v1.model.AgentEventTrigger.notification_enabled', index=10,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=872,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='v1.model.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='v1.model.Condition.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='presence', full_name='v1.model.Condition.presence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='v1.model.Condition.threshold', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regex', full_name='v1.model.Condition.regex', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitset', full_name='v1.model.Condition.bitset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery', full_name='v1.model.Condition.battery', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='v1.model.Condition.numeric', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json', full_name='v1.model.Condition.json', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='autoresolve', full_name='v1.model.Condition.autoresolve', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='condition', full_name='v1.model.Condition.condition',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=875,
  serialized_end=1392,
)


_PRESENCEEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='PresenceEventTriggerCondition',
  full_name='v1.model.PresenceEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1425,
)


_AUTORESOLVEEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='AutoresolveEventTriggerCondition',
  full_name='v1.model.AutoresolveEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1461,
)


_THRESHOLDEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='ThresholdEventTriggerCondition',
  full_name='v1.model.ThresholdEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.ThresholdEventTriggerCondition.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='v1.model.ThresholdEventTriggerCondition.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1557,
)


_NUMERICCONDITION = _descriptor.Descriptor(
  name='NumericCondition',
  full_name='v1.model.NumericCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='v1.model.NumericCondition.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='v1.model.NumericCondition.condition', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1559,
  serialized_end=1653,
)


_NUMERICSETEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='NumericSetEventTriggerCondition',
  full_name='v1.model.NumericSetEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='conditions', full_name='v1.model.NumericSetEventTriggerCondition.conditions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='v1.model.NumericSetEventTriggerCondition.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1656,
  serialized_end=1784,
)


_BATTERYCONDITION = _descriptor.Descriptor(
  name='BatteryCondition',
  full_name='v1.model.BatteryCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='v1.model.BatteryCondition.field', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='v1.model.BatteryCondition.condition', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='v1.model.BatteryCondition.operator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1787,
  serialized_end=1952,
)


_BATTERYEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='BatteryEventTriggerCondition',
  full_name='v1.model.BatteryEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='conditions', full_name='v1.model.BatteryEventTriggerCondition.conditions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='v1.model.BatteryEventTriggerCondition.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1954,
  serialized_end=2079,
)


_REGEXEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='RegexEventTriggerCondition',
  full_name='v1.model.RegexEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='v1.model.RegexEventTriggerCondition.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2081,
  serialized_end=2124,
)


_BITSETEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='BitsetEventTriggerCondition',
  full_name='v1.model.BitsetEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bit_conditions', full_name='v1.model.BitsetEventTriggerCondition.bit_conditions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='v1.model.BitsetEventTriggerCondition.operator', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2126,
  serialized_end=2253,
)


_BITSETCONDITION = _descriptor.Descriptor(
  name='BitsetCondition',
  full_name='v1.model.BitsetCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='v1.model.BitsetCondition.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='true', full_name='v1.model.BitsetCondition.true', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='false', full_name='v1.model.BitsetCondition.false', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2255,
  serialized_end=2314,
)


_JSONEVENTTRIGGERCONDITION = _descriptor.Descriptor(
  name='JsonEventTriggerCondition',
  full_name='v1.model.JsonEventTriggerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jqQuery', full_name='v1.model.JsonEventTriggerCondition.jqQuery', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2316,
  serialized_end=2360,
)


_STATEFULTRIGGERCONFIGURATION = _descriptor.Descriptor(
  name='StatefulTriggerConfiguration',
  full_name='v1.model.StatefulTriggerConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='emitOnEnteringState', full_name='v1.model.StatefulTriggerConfiguration.emitOnEnteringState', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emitOnLeavingState', full_name='v1.model.StatefulTriggerConfiguration.emitOnLeavingState', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2362,
  serialized_end=2449,
)

_EVENT_TAGSENTRY.containing_type = _EVENT
_EVENT.fields_by_name['severity'].enum_type = _SEVERITY
_EVENT.fields_by_name['tags'].message_type = _EVENT_TAGSENTRY
_AGENTEVENTCONFIGURATION.fields_by_name['event_triggers'].message_type = _AGENTEVENTTRIGGER
_AGENTEVENTCONFIGURATION.fields_by_name['stateful_event_triggers'].message_type = _AGENTEVENTTRIGGER
_AGENTEVENTTRIGGER.fields_by_name['condition'].message_type = _CONDITION
_AGENTEVENTTRIGGER.fields_by_name['exitCondition'].message_type = _CONDITION
_AGENTEVENTTRIGGER.fields_by_name['statefulTriggerConfiguration'].message_type = _STATEFULTRIGGERCONFIGURATION
_CONDITION.fields_by_name['presence'].message_type = _PRESENCEEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['threshold'].message_type = _THRESHOLDEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['regex'].message_type = _REGEXEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['bitset'].message_type = _BITSETEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['battery'].message_type = _BATTERYEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['numeric'].message_type = _NUMERICSETEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['json'].message_type = _JSONEVENTTRIGGERCONDITION
_CONDITION.fields_by_name['autoresolve'].message_type = _AUTORESOLVEEVENTTRIGGERCONDITION
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['presence'])
_CONDITION.fields_by_name['presence'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['threshold'])
_CONDITION.fields_by_name['threshold'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['regex'])
_CONDITION.fields_by_name['regex'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['bitset'])
_CONDITION.fields_by_name['bitset'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['battery'])
_CONDITION.fields_by_name['battery'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['numeric'])
_CONDITION.fields_by_name['numeric'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['json'])
_CONDITION.fields_by_name['json'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_CONDITION.oneofs_by_name['condition'].fields.append(
  _CONDITION.fields_by_name['autoresolve'])
_CONDITION.fields_by_name['autoresolve'].containing_oneof = _CONDITION.oneofs_by_name['condition']
_THRESHOLDEVENTTRIGGERCONDITION.fields_by_name['operator'].enum_type = _THRESHOLDOPERATOR
_NUMERICCONDITION.fields_by_name['condition'].message_type = _THRESHOLDEVENTTRIGGERCONDITION
_NUMERICSETEVENTTRIGGERCONDITION.fields_by_name['conditions'].message_type = _NUMERICCONDITION
_NUMERICSETEVENTTRIGGERCONDITION.fields_by_name['operator'].enum_type = _CONDITIONOPERATOR
_BATTERYCONDITION.fields_by_name['field'].enum_type = _BATTERYFIELD
_BATTERYCONDITION.fields_by_name['condition'].message_type = _THRESHOLDEVENTTRIGGERCONDITION
_BATTERYCONDITION.fields_by_name['operator'].enum_type = _CONDITIONOPERATOR
_BATTERYEVENTTRIGGERCONDITION.fields_by_name['conditions'].message_type = _BATTERYCONDITION
_BATTERYEVENTTRIGGERCONDITION.fields_by_name['operator'].enum_type = _CONDITIONOPERATOR
_BITSETEVENTTRIGGERCONDITION.fields_by_name['bit_conditions'].message_type = _BITSETCONDITION
_BITSETEVENTTRIGGERCONDITION.fields_by_name['operator'].enum_type = _CONDITIONOPERATOR
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['AgentEventConfiguration'] = _AGENTEVENTCONFIGURATION
DESCRIPTOR.message_types_by_name['AgentEventTrigger'] = _AGENTEVENTTRIGGER
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.message_types_by_name['PresenceEventTriggerCondition'] = _PRESENCEEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['AutoresolveEventTriggerCondition'] = _AUTORESOLVEEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['ThresholdEventTriggerCondition'] = _THRESHOLDEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['NumericCondition'] = _NUMERICCONDITION
DESCRIPTOR.message_types_by_name['NumericSetEventTriggerCondition'] = _NUMERICSETEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['BatteryCondition'] = _BATTERYCONDITION
DESCRIPTOR.message_types_by_name['BatteryEventTriggerCondition'] = _BATTERYEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['RegexEventTriggerCondition'] = _REGEXEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['BitsetEventTriggerCondition'] = _BITSETEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['BitsetCondition'] = _BITSETCONDITION
DESCRIPTOR.message_types_by_name['JsonEventTriggerCondition'] = _JSONEVENTTRIGGERCONDITION
DESCRIPTOR.message_types_by_name['StatefulTriggerConfiguration'] = _STATEFULTRIGGERCONFIGURATION
DESCRIPTOR.enum_types_by_name['Severity'] = _SEVERITY
DESCRIPTOR.enum_types_by_name['BatteryField'] = _BATTERYFIELD
DESCRIPTOR.enum_types_by_name['ThresholdOperator'] = _THRESHOLDOPERATOR
DESCRIPTOR.enum_types_by_name['ConditionOperator'] = _CONDITIONOPERATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVENT_TAGSENTRY,
    '__module__' : 'protos.model.v1.event_pb2'
    # @@protoc_insertion_point(class_scope:v1.model.Event.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Event)
  })
_sym_db.RegisterMessage(Event)
_sym_db.RegisterMessage(Event.TagsEntry)

AgentEventConfiguration = _reflection.GeneratedProtocolMessageType('AgentEventConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AGENTEVENTCONFIGURATION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AgentEventConfiguration)
  })
_sym_db.RegisterMessage(AgentEventConfiguration)

AgentEventTrigger = _reflection.GeneratedProtocolMessageType('AgentEventTrigger', (_message.Message,), {
  'DESCRIPTOR' : _AGENTEVENTTRIGGER,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AgentEventTrigger)
  })
_sym_db.RegisterMessage(AgentEventTrigger)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
  'DESCRIPTOR' : _CONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.Condition)
  })
_sym_db.RegisterMessage(Condition)

PresenceEventTriggerCondition = _reflection.GeneratedProtocolMessageType('PresenceEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _PRESENCEEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.PresenceEventTriggerCondition)
  })
_sym_db.RegisterMessage(PresenceEventTriggerCondition)

AutoresolveEventTriggerCondition = _reflection.GeneratedProtocolMessageType('AutoresolveEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _AUTORESOLVEEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.AutoresolveEventTriggerCondition)
  })
_sym_db.RegisterMessage(AutoresolveEventTriggerCondition)

ThresholdEventTriggerCondition = _reflection.GeneratedProtocolMessageType('ThresholdEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _THRESHOLDEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ThresholdEventTriggerCondition)
  })
_sym_db.RegisterMessage(ThresholdEventTriggerCondition)

NumericCondition = _reflection.GeneratedProtocolMessageType('NumericCondition', (_message.Message,), {
  'DESCRIPTOR' : _NUMERICCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.NumericCondition)
  })
_sym_db.RegisterMessage(NumericCondition)

NumericSetEventTriggerCondition = _reflection.GeneratedProtocolMessageType('NumericSetEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _NUMERICSETEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.NumericSetEventTriggerCondition)
  })
_sym_db.RegisterMessage(NumericSetEventTriggerCondition)

BatteryCondition = _reflection.GeneratedProtocolMessageType('BatteryCondition', (_message.Message,), {
  'DESCRIPTOR' : _BATTERYCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.BatteryCondition)
  })
_sym_db.RegisterMessage(BatteryCondition)

BatteryEventTriggerCondition = _reflection.GeneratedProtocolMessageType('BatteryEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _BATTERYEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.BatteryEventTriggerCondition)
  })
_sym_db.RegisterMessage(BatteryEventTriggerCondition)

RegexEventTriggerCondition = _reflection.GeneratedProtocolMessageType('RegexEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _REGEXEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.RegexEventTriggerCondition)
  })
_sym_db.RegisterMessage(RegexEventTriggerCondition)

BitsetEventTriggerCondition = _reflection.GeneratedProtocolMessageType('BitsetEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _BITSETEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.BitsetEventTriggerCondition)
  })
_sym_db.RegisterMessage(BitsetEventTriggerCondition)

BitsetCondition = _reflection.GeneratedProtocolMessageType('BitsetCondition', (_message.Message,), {
  'DESCRIPTOR' : _BITSETCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.BitsetCondition)
  })
_sym_db.RegisterMessage(BitsetCondition)

JsonEventTriggerCondition = _reflection.GeneratedProtocolMessageType('JsonEventTriggerCondition', (_message.Message,), {
  'DESCRIPTOR' : _JSONEVENTTRIGGERCONDITION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.JsonEventTriggerCondition)
  })
_sym_db.RegisterMessage(JsonEventTriggerCondition)

StatefulTriggerConfiguration = _reflection.GeneratedProtocolMessageType('StatefulTriggerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _STATEFULTRIGGERCONFIGURATION,
  '__module__' : 'protos.model.v1.event_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.StatefulTriggerConfiguration)
  })
_sym_db.RegisterMessage(StatefulTriggerConfiguration)


DESCRIPTOR._options = None
_EVENT_TAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)



import unittest
from formant.sdk.cloud.v2.src.query_api import QueryAPI
from formant.sdk.cloud.v2.formant_query_api_client.models.interval_query import (
    IntervalQuery,
)
from formant.sdk.cloud.v2.formant_query_api_client.models.interval_query_interval import (
    IntervalQueryInterval,
)
import dateutil.parser as parser
import os

EMAIL = os.getenv("FORMANT_EMAIL")
PASSWORD = os.getenv("FORMANT_PASSWORD")
BASE_URL = "https://api.formant.io/v1"


class TestPresence(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(TestPresence, self).__init__(*args, **kwargs)
        self.client = QueryAPI(email=EMAIL, password=PASSWORD, base_url=BASE_URL)

    def test_online(self):
        interval_query_interval = IntervalQueryInterval("minute")
        start = parser.isoparse("2022-12-11T02:00:00.000Z")
        end = parser.isoparse("2022-12-11T02:02:00.000Z")
        interval_query = IntervalQuery(interval_query_interval, start, end)

        response = self.client.presence.count(interval_query)
        self.assertEqual(response.status_code, 200)


unittest.main()




from formant.sdk.cloud.v2.formant_admin_api_client.models import ScopeFilter, AnnotationTemplateListResponse, ScopeFilterTypesItem, AnnotationFieldValue, AnnotationTemplate, SheetParameters, AnnotationTags, AnnotationFieldValueTags, TagParameters, AnnotationMetadata, AnnotationFieldValuesRequestTags, AnnotationType, Annotation, UserParameters, AnnotationFieldType, UserParametersRolesItem, AnnotationField, AnnotationFieldValuesResponse, AnnotationFieldValuesRequest, AnnotationStreamType, AnnotationTemplateTags
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar
from formant.sdk.cloud.v2.formant_query_api_client.models.bitset import Bitset
from formant.sdk.cloud.v2.formant_query_api_client.models.localization import (
    Localization,
)
from formant.sdk.cloud.v2.formant_query_api_client.models.point_cloud import PointCloud
from formant.sdk.cloud.v2.formant_query_api_client.models.location import Location
from formant.sdk.cloud.v2.formant_query_api_client.models.file import File
from formant.sdk.cloud.v2.formant_query_api_client.models.health import (
    Health,
    HealthStatus,
)
from formant.sdk.cloud.v2.formant_query_api_client.models.transform_node import (
    TransformNode,
)
from formant.sdk.cloud.v2.formant_query_api_client.models.battery import Battery
from formant.sdk.cloud.v2.formant_query_api_client.models.video import (
    Video,
    VideoMimeType,
)
from formant.sdk.cloud.v2.formant_query_api_client.models.numeric_set_entry import (
    NumericSetEntry,
)
from formant.sdk.cloud.v2.formant_query_api_client.models.image import Image

from datetime import datetime
from urllib.request import urlopen
import attr

T = TypeVar("T", bound="StreamDataPointsItem")

TYPE_MAP = {
    "bitset": Bitset,
    "localization": Localization,
    "point cloud": PointCloud,
    "location": Location,
    "file": File,
    "health": Health,
    "transform tree": TransformNode,
    "battery": Battery,
    "video": Video,
    "image": Image,
}


@attr.s(auto_attribs=True)
class StreamDataPointsItem:
    """ """

    timestamp: datetime = None
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    bitset: Bitset = None
    localization: Localization = None
    point_cloud: PointCloud = None
    location: Location = None
    file: File = None
    health: Health = None
    transform_tree: TransformNode = None
    battery: Battery = None
    video: Video = None
    numeric_set: List[NumericSetEntry] = None
    json: Dict = None
    image: Image = None
    numeric: float = None
    text: str = None

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], raw_data: List, type: str) -> T:

        d = raw_data.copy()
        stream_data_points_item = cls()
        raw_timestamp = raw_data[0] / 1000.0
        stream_data_points_item.timestamp = datetime.fromtimestamp(raw_timestamp)
        stream_data_points_item.initialize_data(type=type, raw_data=raw_data[1])
        stream_data_points_item.additional_properties = {"value": d}
        return stream_data_points_item

    def initialize_data(self, type: str, raw_data: Any):

        if type == "numeric set":
            numeric_set_instance = []
            for raw_entry in raw_data:
                raw_entry_instance = NumericSetEntry.from_dict(raw_entry)
                numeric_set_instance.append(raw_entry_instance)
            self.numeric_set = numeric_set_instance

        elif type == "json":
            self.json = raw_data

        elif type == "numeric":
            self.numeric = raw_data

        elif type == "text":
            self.text = raw_data

        else:
            custom_data = TYPE_MAP[type].from_dict(raw_data)
            type_new = type.replace(" ", "_")
            setattr(self, type_new, custom_data)

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.joystick_configuration_angular import JoystickConfigurationAngular
from ..models.joystick_configuration_linear import JoystickConfigurationLinear

T = TypeVar("T", bound="JoystickConfiguration")


@attr.s(auto_attribs=True)
class JoystickConfiguration:
    """
    Attributes:
        linear (JoystickConfigurationLinear):
        angular (JoystickConfigurationAngular):
        scale (float):
        sensitivity (float):
    """

    linear: JoystickConfigurationLinear
    angular: JoystickConfigurationAngular
    scale: float
    sensitivity: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        linear = self.linear.value

        angular = self.angular.value

        scale = self.scale
        sensitivity = self.sensitivity

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "linear": linear,
                "angular": angular,
                "scale": scale,
                "sensitivity": sensitivity,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        linear = JoystickConfigurationLinear(d.pop("linear"))

        angular = JoystickConfigurationAngular(d.pop("angular"))

        scale = d.pop("scale")

        sensitivity = d.pop("sensitivity")

        joystick_configuration = cls(
            linear=linear,
            angular=angular,
            scale=scale,
            sensitivity=sensitivity,
        )

        joystick_configuration.additional_properties = d
        return joystick_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="RespondToNewPasswordRequiredChallengeRequest")


@attr.s(auto_attribs=True)
class RespondToNewPasswordRequiredChallengeRequest:
    """
    Attributes:
        user_id (str):
        session (str):
        new_password (str):
    """

    user_id: str
    session: str
    new_password: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        user_id = self.user_id
        session = self.session
        new_password = self.new_password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "userId": user_id,
                "session": session,
                "newPassword": new_password,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        user_id = d.pop("userId")

        session = d.pop("session")

        new_password = d.pop("newPassword")

        respond_to_new_password_required_challenge_request = cls(
            user_id=user_id,
            session=session,
            new_password=new_password,
        )

        respond_to_new_password_required_challenge_request.additional_properties = d
        return respond_to_new_password_required_challenge_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_query_api_client.models import ScopeFilter, Metadata, ScopeFilterTypesItem, MetadataTags, StreamCurrentValueListResponse, MetadataType
from formant.sdk.cloud.v2.formant_query_api_client.api.stream_current_value import stream_current_value_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *



from . import commands_pb2
from . import config_pb2
from . import datapoint_pb2
from . import event_pb2
from . import file_pb2
from . import health_pb2
from . import intervention_pb2
from . import math_pb2
from . import media_pb2
from . import navigation_pb2
from . import ros_pb2
from . import text_pb2
from . import views_pb2

from . import commands_pb2_grpc
from . import config_pb2_grpc
from . import datapoint_pb2_grpc
from . import event_pb2_grpc
from . import file_pb2_grpc
from . import health_pb2_grpc
from . import intervention_pb2_grpc
from . import math_pb2_grpc
from . import media_pb2_grpc
from . import navigation_pb2_grpc
from . import ros_pb2_grpc
from . import text_pb2_grpc
from . import views_pb2_grpc



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.user_parameters_roles_item import UserParametersRolesItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserParameters")


@attr.s(auto_attribs=True)
class UserParameters:
    """
    Attributes:
        roles (Union[Unset, List[UserParametersRolesItem]]):
    """

    roles: Union[Unset, List[UserParametersRolesItem]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        roles: Union[Unset, List[str]] = UNSET
        if not isinstance(self.roles, Unset):
            roles = []
            for roles_item_data in self.roles:
                roles_item = roles_item_data.value

                roles.append(roles_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if roles is not UNSET:
            field_dict["roles"] = roles

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        roles = []
        _roles = d.pop("roles", UNSET)
        for roles_item_data in _roles or []:
            roles_item = UserParametersRolesItem(roles_item_data)

            roles.append(roles_item)

        user_parameters = cls(
            roles=roles,
        )

        user_parameters.additional_properties = d
        return user_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_query_api_client.models import Battery, Location, ImageAnnotation, StreamDataPointsItem, Video,VideoMimeType, BoundingBox, Query, NumericSetEntry, QueryTypesItem, Odometry, Path, Video, StreamData, StreamDataTags, File, QueryAggregate, Goal, Map, StreamAggregateData, Health, HealthStatus, TransformNode, Transform, Bitset, Health,HealthStatus, Image, Localization, StreamDataListResponse, PointCloud, StreamAggregateDataType, StreamAggregateDataTags, Twist, VideoMimeType, Vector3, Quaternion, StreamDataType
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.device_stream_directory_watch_configuration_file_type import (
    DeviceStreamDirectoryWatchConfigurationFileType,
)
from ..models.device_stream_directory_watch_configuration_type import DeviceStreamDirectoryWatchConfigurationType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceStreamDirectoryWatchConfiguration")


@attr.s(auto_attribs=True)
class DeviceStreamDirectoryWatchConfiguration:
    """
    Attributes:
        type (DeviceStreamDirectoryWatchConfigurationType):
        directory (str):
        extension (Union[Unset, str]):
        file_type (Union[Unset, DeviceStreamDirectoryWatchConfigurationFileType]):
    """

    type: DeviceStreamDirectoryWatchConfigurationType
    directory: str
    extension: Union[Unset, str] = UNSET
    file_type: Union[Unset, DeviceStreamDirectoryWatchConfigurationFileType] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type.value

        directory = self.directory
        extension = self.extension
        file_type: Union[Unset, str] = UNSET
        if not isinstance(self.file_type, Unset):
            file_type = self.file_type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "directory": directory,
            }
        )
        if extension is not UNSET:
            field_dict["extension"] = extension
        if file_type is not UNSET:
            field_dict["fileType"] = file_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = DeviceStreamDirectoryWatchConfigurationType(d.pop("type"))

        directory = d.pop("directory")

        extension = d.pop("extension", UNSET)

        _file_type = d.pop("fileType", UNSET)
        file_type: Union[Unset, DeviceStreamDirectoryWatchConfigurationFileType]
        if isinstance(_file_type, Unset):
            file_type = UNSET
        else:
            file_type = DeviceStreamDirectoryWatchConfigurationFileType(_file_type)

        device_stream_directory_watch_configuration = cls(
            type=type,
            directory=directory,
            extension=extension,
            file_type=file_type,
        )

        device_stream_directory_watch_configuration.additional_properties = d
        return device_stream_directory_watch_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="Vector3")


@attr.s(auto_attribs=True)
class Vector3:
    """
    Attributes:
        x (float):
        y (float):
        z (float):
    """

    x: float
    y: float
    z: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        x = self.x
        y = self.y
        z = self.z

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "x": x,
                "y": y,
                "z": z,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        x = d.pop("x")

        y = d.pop("y")

        z = d.pop("z")

        vector_3 = cls(
            x=x,
            y=y,
            z=z,
        )

        vector_3.additional_properties = d
        return vector_3

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Optional
from uuid import uuid4
from .internal_types import PointField
from .point_cloud2 import create_cloud, pointcloud2_to_formant_pointcloud
from .laserscan import laserscan_to_formant_pointcloud

from formant.protos.model.v1 import media_pb2
from formant.sdk.agent.v1.localization.utils import get_ros_module, validate_type
from formant.sdk.agent.v1.localization.types import Transform


class PointCloud:
    @classmethod
    def from_xyzi32(cls, points):
        fields = [
            PointField(name="x", offset=0, datatype=PointField.FLOAT32, count=1),
            PointField(name="y", offset=4, datatype=PointField.FLOAT32, count=1),
            PointField(name="z", offset=8, datatype=PointField.FLOAT32, count=1),
            PointField(
                name="intensity", offset=12, datatype=PointField.FLOAT32, count=1
            ),
        ]
        point_cloud2 = create_cloud(fields, points)
        data = pointcloud2_to_formant_pointcloud(point_cloud2)
        return cls(data=data)

    @classmethod
    def from_ros(cls, point_cloud2):
        sensor_msgs = get_ros_module("sensor_msgs.msg")
        validate_type(point_cloud2, sensor_msgs.PointCloud2)
        data = pointcloud2_to_formant_pointcloud(point_cloud2)
        return cls(data=data)

    @classmethod
    def from_ros_laserscan(cls, laserscan):
        sensor_msgs = get_ros_module("sensor_msgs.msg")
        validate_type(laserscan, sensor_msgs.LaserScan)
        data = laserscan_to_formant_pointcloud(laserscan)
        return cls(data=data)

    def __init__(
        self,
        data=None,  # type: Optional[bytes]
        url=None,  # type:  Optional[str]
        transform_to_world=Transform(),  # type: Transform
    ):
        self.data = data
        self.url = url
        self.transform_to_world = transform_to_world
        self.uuid = uuid4()

    def to_proto(self):
        return media_pb2.PointCloud(
            raw=self.data,
            url=self.url,
            world_to_local=self.transform_to_world.to_proto(),
            uuid=str(self.uuid),
        )


def create_cloud_xyzi32(points):

    fields = [
        PointField(name="x", offset=0, datatype=PointField.FLOAT32, count=1),
        PointField(name="y", offset=4, datatype=PointField.FLOAT32, count=1),
        PointField(name="z", offset=8, datatype=PointField.FLOAT32, count=1),
        PointField(name="intensity", offset=12, datatype=PointField.FLOAT32, count=1),
    ]
    point_cloud2 = create_cloud(fields, points)
    return pointcloud2_to_formant_pointcloud(point_cloud2)



from enum import Enum


class SqlQueryAggregateType(str, Enum):
    AVG = "avg"
    SUM = "sum"
    COUNT = "count"
    MIN = "min"
    MAX = "max"
    MEDIAN = "median"
    STD_DEV = "std_dev"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.partial_event_trigger_event_type import PartialEventTriggerEventType
from ..models.partial_event_trigger_severity import PartialEventTriggerSeverity
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.auto_resolve_event_trigger_condition import AutoResolveEventTriggerCondition
    from ..models.base_event_trigger_predicate import BaseEventTriggerPredicate
    from ..models.battery_event_trigger_condition import BatteryEventTriggerCondition
    from ..models.bitset_event_trigger_condition import BitsetEventTriggerCondition
    from ..models.event_trigger_command import EventTriggerCommand
    from ..models.forwarding_configuration import ForwardingConfiguration
    from ..models.json_event_trigger_condition import JsonEventTriggerCondition
    from ..models.numeric_set_event_trigger_condition import NumericSetEventTriggerCondition
    from ..models.partial_event_trigger_sms_tags import PartialEventTriggerSmsTags
    from ..models.partial_event_trigger_tags import PartialEventTriggerTags
    from ..models.presence_event_trigger_condition import PresenceEventTriggerCondition
    from ..models.regex_event_trigger_condition import RegexEventTriggerCondition
    from ..models.scope_filter import ScopeFilter
    from ..models.stateful_trigger_configuration import StatefulTriggerConfiguration
    from ..models.threshold_event_trigger_condition import ThresholdEventTriggerCondition
    from ..models.triggered_configuration import TriggeredConfiguration


T = TypeVar("T", bound="PartialEventTrigger")


@attr.s(auto_attribs=True)
class PartialEventTrigger:
    """
    Attributes:
        organization_id (Union[Unset, str]):
        event_type (Union[Unset, PartialEventTriggerEventType]):
        message (Union[Unset, str]):
        condition (Union['AutoResolveEventTriggerCondition', 'BatteryEventTriggerCondition',
            'BitsetEventTriggerCondition', 'JsonEventTriggerCondition', 'NumericSetEventTriggerCondition',
            'PresenceEventTriggerCondition', 'RegexEventTriggerCondition', 'ThresholdEventTriggerCondition', None, Unset]):
        exit_condition (Union['AutoResolveEventTriggerCondition', 'BatteryEventTriggerCondition',
            'BitsetEventTriggerCondition', 'JsonEventTriggerCondition', 'NumericSetEventTriggerCondition',
            'PresenceEventTriggerCondition', 'RegexEventTriggerCondition', 'ThresholdEventTriggerCondition', None, Unset]):
        predicate (Union['BaseEventTriggerPredicate', None, Unset]):
        interval (Union[Unset, int]):
        severity (Union[Unset, PartialEventTriggerSeverity]):
        enabled (Union[Unset, bool]):
        format_ (Union[Unset, str]):
        triggered_configuration (Union[Unset, None, TriggeredConfiguration]):
        sms_tags (Union[Unset, PartialEventTriggerSmsTags]):
        device_scope (Union[Unset, None, ScopeFilter]):
        commands (Union[Unset, List['EventTriggerCommand']]):
        notification_enabled (Union[Unset, bool]):
        last_triggered_time (Union[Unset, None, datetime.datetime]):
        event_trigger_group_id (Union[Unset, None, str]):
        stateful_trigger_configuration (Union[Unset, None, StatefulTriggerConfiguration]):
        is_stateful (Union[Unset, bool]):
        forwarding_configuration (Union[Unset, None, ForwardingConfiguration]):
        sets_device_color (Union[Unset, bool]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
        tags (Union[Unset, PartialEventTriggerTags]):
    """

    organization_id: Union[Unset, str] = UNSET
    event_type: Union[Unset, PartialEventTriggerEventType] = UNSET
    message: Union[Unset, str] = UNSET
    condition: Union[
        "AutoResolveEventTriggerCondition",
        "BatteryEventTriggerCondition",
        "BitsetEventTriggerCondition",
        "JsonEventTriggerCondition",
        "NumericSetEventTriggerCondition",
        "PresenceEventTriggerCondition",
        "RegexEventTriggerCondition",
        "ThresholdEventTriggerCondition",
        None,
        Unset,
    ] = UNSET
    exit_condition: Union[
        "AutoResolveEventTriggerCondition",
        "BatteryEventTriggerCondition",
        "BitsetEventTriggerCondition",
        "JsonEventTriggerCondition",
        "NumericSetEventTriggerCondition",
        "PresenceEventTriggerCondition",
        "RegexEventTriggerCondition",
        "ThresholdEventTriggerCondition",
        None,
        Unset,
    ] = UNSET
    predicate: Union["BaseEventTriggerPredicate", None, Unset] = UNSET
    interval: Union[Unset, int] = UNSET
    severity: Union[Unset, PartialEventTriggerSeverity] = UNSET
    enabled: Union[Unset, bool] = UNSET
    format_: Union[Unset, str] = UNSET
    triggered_configuration: Union[Unset, None, "TriggeredConfiguration"] = UNSET
    sms_tags: Union[Unset, "PartialEventTriggerSmsTags"] = UNSET
    device_scope: Union[Unset, None, "ScopeFilter"] = UNSET
    commands: Union[Unset, List["EventTriggerCommand"]] = UNSET
    notification_enabled: Union[Unset, bool] = UNSET
    last_triggered_time: Union[Unset, None, datetime.datetime] = UNSET
    event_trigger_group_id: Union[Unset, None, str] = UNSET
    stateful_trigger_configuration: Union[Unset, None, "StatefulTriggerConfiguration"] = UNSET
    is_stateful: Union[Unset, bool] = UNSET
    forwarding_configuration: Union[Unset, None, "ForwardingConfiguration"] = UNSET
    sets_device_color: Union[Unset, bool] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    tags: Union[Unset, "PartialEventTriggerTags"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.base_event_trigger_predicate import BaseEventTriggerPredicate
        from ..models.battery_event_trigger_condition import BatteryEventTriggerCondition
        from ..models.bitset_event_trigger_condition import BitsetEventTriggerCondition
        from ..models.json_event_trigger_condition import JsonEventTriggerCondition
        from ..models.numeric_set_event_trigger_condition import NumericSetEventTriggerCondition
        from ..models.presence_event_trigger_condition import PresenceEventTriggerCondition
        from ..models.regex_event_trigger_condition import RegexEventTriggerCondition
        from ..models.threshold_event_trigger_condition import ThresholdEventTriggerCondition

        organization_id = self.organization_id
        event_type: Union[Unset, str] = UNSET
        if not isinstance(self.event_type, Unset):
            event_type = self.event_type.value

        message = self.message
        condition: Union[Dict[str, Any], None, Unset]
        if isinstance(self.condition, Unset):
            condition = UNSET
        elif self.condition is None:
            condition = None

        elif isinstance(self.condition, PresenceEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        elif isinstance(self.condition, ThresholdEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        elif isinstance(self.condition, RegexEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        elif isinstance(self.condition, BitsetEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        elif isinstance(self.condition, BatteryEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        elif isinstance(self.condition, NumericSetEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        elif isinstance(self.condition, JsonEventTriggerCondition):
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        else:
            condition = UNSET
            if not isinstance(self.condition, Unset):
                condition = self.condition.to_dict()

        exit_condition: Union[Dict[str, Any], None, Unset]
        if isinstance(self.exit_condition, Unset):
            exit_condition = UNSET
        elif self.exit_condition is None:
            exit_condition = None

        elif isinstance(self.exit_condition, PresenceEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        elif isinstance(self.exit_condition, ThresholdEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        elif isinstance(self.exit_condition, RegexEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        elif isinstance(self.exit_condition, BitsetEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        elif isinstance(self.exit_condition, BatteryEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        elif isinstance(self.exit_condition, NumericSetEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        elif isinstance(self.exit_condition, JsonEventTriggerCondition):
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        else:
            exit_condition = UNSET
            if not isinstance(self.exit_condition, Unset):
                exit_condition = self.exit_condition.to_dict()

        predicate: Union[Dict[str, Any], None, Unset]
        if isinstance(self.predicate, Unset):
            predicate = UNSET
        elif self.predicate is None:
            predicate = None

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        elif isinstance(self.predicate, BaseEventTriggerPredicate):
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        else:
            predicate = UNSET
            if not isinstance(self.predicate, Unset):
                predicate = self.predicate.to_dict()

        interval = self.interval
        severity: Union[Unset, str] = UNSET
        if not isinstance(self.severity, Unset):
            severity = self.severity.value

        enabled = self.enabled
        format_ = self.format_
        triggered_configuration: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.triggered_configuration, Unset):
            triggered_configuration = self.triggered_configuration.to_dict() if self.triggered_configuration else None

        sms_tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sms_tags, Unset):
            sms_tags = self.sms_tags.to_dict()

        device_scope: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.device_scope, Unset):
            device_scope = self.device_scope.to_dict() if self.device_scope else None

        commands: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.commands, Unset):
            commands = []
            for commands_item_data in self.commands:
                commands_item = commands_item_data.to_dict()

                commands.append(commands_item)

        notification_enabled = self.notification_enabled
        last_triggered_time: Union[Unset, None, str] = UNSET
        if not isinstance(self.last_triggered_time, Unset):
            last_triggered_time = self.last_triggered_time.isoformat() if self.last_triggered_time else None

        event_trigger_group_id = self.event_trigger_group_id
        stateful_trigger_configuration: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.stateful_trigger_configuration, Unset):
            stateful_trigger_configuration = (
                self.stateful_trigger_configuration.to_dict() if self.stateful_trigger_configuration else None
            )

        is_stateful = self.is_stateful
        forwarding_configuration: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.forwarding_configuration, Unset):
            forwarding_configuration = (
                self.forwarding_configuration.to_dict() if self.forwarding_configuration else None
            )

        sets_device_color = self.sets_device_color
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if event_type is not UNSET:
            field_dict["eventType"] = event_type
        if message is not UNSET:
            field_dict["message"] = message
        if condition is not UNSET:
            field_dict["condition"] = condition
        if exit_condition is not UNSET:
            field_dict["exitCondition"] = exit_condition
        if predicate is not UNSET:
            field_dict["predicate"] = predicate
        if interval is not UNSET:
            field_dict["interval"] = interval
        if severity is not UNSET:
            field_dict["severity"] = severity
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if format_ is not UNSET:
            field_dict["format"] = format_
        if triggered_configuration is not UNSET:
            field_dict["triggeredConfiguration"] = triggered_configuration
        if sms_tags is not UNSET:
            field_dict["smsTags"] = sms_tags
        if device_scope is not UNSET:
            field_dict["deviceScope"] = device_scope
        if commands is not UNSET:
            field_dict["commands"] = commands
        if notification_enabled is not UNSET:
            field_dict["notificationEnabled"] = notification_enabled
        if last_triggered_time is not UNSET:
            field_dict["lastTriggeredTime"] = last_triggered_time
        if event_trigger_group_id is not UNSET:
            field_dict["eventTriggerGroupId"] = event_trigger_group_id
        if stateful_trigger_configuration is not UNSET:
            field_dict["statefulTriggerConfiguration"] = stateful_trigger_configuration
        if is_stateful is not UNSET:
            field_dict["isStateful"] = is_stateful
        if forwarding_configuration is not UNSET:
            field_dict["forwardingConfiguration"] = forwarding_configuration
        if sets_device_color is not UNSET:
            field_dict["setsDeviceColor"] = sets_device_color
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if tags is not UNSET:
            field_dict["tags"] = tags

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.auto_resolve_event_trigger_condition import AutoResolveEventTriggerCondition
        from ..models.base_event_trigger_predicate import BaseEventTriggerPredicate
        from ..models.battery_event_trigger_condition import BatteryEventTriggerCondition
        from ..models.bitset_event_trigger_condition import BitsetEventTriggerCondition
        from ..models.event_trigger_command import EventTriggerCommand
        from ..models.forwarding_configuration import ForwardingConfiguration
        from ..models.json_event_trigger_condition import JsonEventTriggerCondition
        from ..models.numeric_set_event_trigger_condition import NumericSetEventTriggerCondition
        from ..models.partial_event_trigger_sms_tags import PartialEventTriggerSmsTags
        from ..models.partial_event_trigger_tags import PartialEventTriggerTags
        from ..models.presence_event_trigger_condition import PresenceEventTriggerCondition
        from ..models.regex_event_trigger_condition import RegexEventTriggerCondition
        from ..models.scope_filter import ScopeFilter
        from ..models.stateful_trigger_configuration import StatefulTriggerConfiguration
        from ..models.threshold_event_trigger_condition import ThresholdEventTriggerCondition
        from ..models.triggered_configuration import TriggeredConfiguration

        d = src_dict.copy()
        organization_id = d.pop("organizationId", UNSET)

        _event_type = d.pop("eventType", UNSET)
        event_type: Union[Unset, PartialEventTriggerEventType]
        if isinstance(_event_type, Unset):
            event_type = UNSET
        else:
            event_type = PartialEventTriggerEventType(_event_type)

        message = d.pop("message", UNSET)

        def _parse_condition(
            data: object,
        ) -> Union[
            "AutoResolveEventTriggerCondition",
            "BatteryEventTriggerCondition",
            "BitsetEventTriggerCondition",
            "JsonEventTriggerCondition",
            "NumericSetEventTriggerCondition",
            "PresenceEventTriggerCondition",
            "RegexEventTriggerCondition",
            "ThresholdEventTriggerCondition",
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_0 = data
                condition_type_0: Union[Unset, PresenceEventTriggerCondition]
                if isinstance(_condition_type_0, Unset):
                    condition_type_0 = UNSET
                else:
                    condition_type_0 = PresenceEventTriggerCondition.from_dict(_condition_type_0)

                return condition_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_1 = data
                condition_type_1: Union[Unset, ThresholdEventTriggerCondition]
                if isinstance(_condition_type_1, Unset):
                    condition_type_1 = UNSET
                else:
                    condition_type_1 = ThresholdEventTriggerCondition.from_dict(_condition_type_1)

                return condition_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_2 = data
                condition_type_2: Union[Unset, RegexEventTriggerCondition]
                if isinstance(_condition_type_2, Unset):
                    condition_type_2 = UNSET
                else:
                    condition_type_2 = RegexEventTriggerCondition.from_dict(_condition_type_2)

                return condition_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_3 = data
                condition_type_3: Union[Unset, BitsetEventTriggerCondition]
                if isinstance(_condition_type_3, Unset):
                    condition_type_3 = UNSET
                else:
                    condition_type_3 = BitsetEventTriggerCondition.from_dict(_condition_type_3)

                return condition_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_4 = data
                condition_type_4: Union[Unset, BatteryEventTriggerCondition]
                if isinstance(_condition_type_4, Unset):
                    condition_type_4 = UNSET
                else:
                    condition_type_4 = BatteryEventTriggerCondition.from_dict(_condition_type_4)

                return condition_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_5 = data
                condition_type_5: Union[Unset, NumericSetEventTriggerCondition]
                if isinstance(_condition_type_5, Unset):
                    condition_type_5 = UNSET
                else:
                    condition_type_5 = NumericSetEventTriggerCondition.from_dict(_condition_type_5)

                return condition_type_5
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _condition_type_6 = data
                condition_type_6: Union[Unset, JsonEventTriggerCondition]
                if isinstance(_condition_type_6, Unset):
                    condition_type_6 = UNSET
                else:
                    condition_type_6 = JsonEventTriggerCondition.from_dict(_condition_type_6)

                return condition_type_6
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            _condition_type_7 = data
            condition_type_7: Union[Unset, AutoResolveEventTriggerCondition]
            if isinstance(_condition_type_7, Unset):
                condition_type_7 = UNSET
            else:
                condition_type_7 = AutoResolveEventTriggerCondition.from_dict(_condition_type_7)

            return condition_type_7

        condition = _parse_condition(d.pop("condition", UNSET))

        def _parse_exit_condition(
            data: object,
        ) -> Union[
            "AutoResolveEventTriggerCondition",
            "BatteryEventTriggerCondition",
            "BitsetEventTriggerCondition",
            "JsonEventTriggerCondition",
            "NumericSetEventTriggerCondition",
            "PresenceEventTriggerCondition",
            "RegexEventTriggerCondition",
            "ThresholdEventTriggerCondition",
            None,
            Unset,
        ]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_0 = data
                exit_condition_type_0: Union[Unset, PresenceEventTriggerCondition]
                if isinstance(_exit_condition_type_0, Unset):
                    exit_condition_type_0 = UNSET
                else:
                    exit_condition_type_0 = PresenceEventTriggerCondition.from_dict(_exit_condition_type_0)

                return exit_condition_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_1 = data
                exit_condition_type_1: Union[Unset, ThresholdEventTriggerCondition]
                if isinstance(_exit_condition_type_1, Unset):
                    exit_condition_type_1 = UNSET
                else:
                    exit_condition_type_1 = ThresholdEventTriggerCondition.from_dict(_exit_condition_type_1)

                return exit_condition_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_2 = data
                exit_condition_type_2: Union[Unset, RegexEventTriggerCondition]
                if isinstance(_exit_condition_type_2, Unset):
                    exit_condition_type_2 = UNSET
                else:
                    exit_condition_type_2 = RegexEventTriggerCondition.from_dict(_exit_condition_type_2)

                return exit_condition_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_3 = data
                exit_condition_type_3: Union[Unset, BitsetEventTriggerCondition]
                if isinstance(_exit_condition_type_3, Unset):
                    exit_condition_type_3 = UNSET
                else:
                    exit_condition_type_3 = BitsetEventTriggerCondition.from_dict(_exit_condition_type_3)

                return exit_condition_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_4 = data
                exit_condition_type_4: Union[Unset, BatteryEventTriggerCondition]
                if isinstance(_exit_condition_type_4, Unset):
                    exit_condition_type_4 = UNSET
                else:
                    exit_condition_type_4 = BatteryEventTriggerCondition.from_dict(_exit_condition_type_4)

                return exit_condition_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_5 = data
                exit_condition_type_5: Union[Unset, NumericSetEventTriggerCondition]
                if isinstance(_exit_condition_type_5, Unset):
                    exit_condition_type_5 = UNSET
                else:
                    exit_condition_type_5 = NumericSetEventTriggerCondition.from_dict(_exit_condition_type_5)

                return exit_condition_type_5
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _exit_condition_type_6 = data
                exit_condition_type_6: Union[Unset, JsonEventTriggerCondition]
                if isinstance(_exit_condition_type_6, Unset):
                    exit_condition_type_6 = UNSET
                else:
                    exit_condition_type_6 = JsonEventTriggerCondition.from_dict(_exit_condition_type_6)

                return exit_condition_type_6
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            _exit_condition_type_7 = data
            exit_condition_type_7: Union[Unset, AutoResolveEventTriggerCondition]
            if isinstance(_exit_condition_type_7, Unset):
                exit_condition_type_7 = UNSET
            else:
                exit_condition_type_7 = AutoResolveEventTriggerCondition.from_dict(_exit_condition_type_7)

            return exit_condition_type_7

        exit_condition = _parse_exit_condition(d.pop("exitCondition", UNSET))

        def _parse_predicate(data: object) -> Union["BaseEventTriggerPredicate", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_0 = data
                predicate_type_0: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_0, Unset):
                    predicate_type_0 = UNSET
                else:
                    predicate_type_0 = BaseEventTriggerPredicate.from_dict(_predicate_type_0)

                return predicate_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_1 = data
                predicate_type_1: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_1, Unset):
                    predicate_type_1 = UNSET
                else:
                    predicate_type_1 = BaseEventTriggerPredicate.from_dict(_predicate_type_1)

                return predicate_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_2 = data
                predicate_type_2: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_2, Unset):
                    predicate_type_2 = UNSET
                else:
                    predicate_type_2 = BaseEventTriggerPredicate.from_dict(_predicate_type_2)

                return predicate_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_3 = data
                predicate_type_3: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_3, Unset):
                    predicate_type_3 = UNSET
                else:
                    predicate_type_3 = BaseEventTriggerPredicate.from_dict(_predicate_type_3)

                return predicate_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_4 = data
                predicate_type_4: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_4, Unset):
                    predicate_type_4 = UNSET
                else:
                    predicate_type_4 = BaseEventTriggerPredicate.from_dict(_predicate_type_4)

                return predicate_type_4
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_5 = data
                predicate_type_5: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_5, Unset):
                    predicate_type_5 = UNSET
                else:
                    predicate_type_5 = BaseEventTriggerPredicate.from_dict(_predicate_type_5)

                return predicate_type_5
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_6 = data
                predicate_type_6: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_6, Unset):
                    predicate_type_6 = UNSET
                else:
                    predicate_type_6 = BaseEventTriggerPredicate.from_dict(_predicate_type_6)

                return predicate_type_6
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_7 = data
                predicate_type_7: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_7, Unset):
                    predicate_type_7 = UNSET
                else:
                    predicate_type_7 = BaseEventTriggerPredicate.from_dict(_predicate_type_7)

                return predicate_type_7
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_8 = data
                predicate_type_8: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_8, Unset):
                    predicate_type_8 = UNSET
                else:
                    predicate_type_8 = BaseEventTriggerPredicate.from_dict(_predicate_type_8)

                return predicate_type_8
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_9 = data
                predicate_type_9: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_9, Unset):
                    predicate_type_9 = UNSET
                else:
                    predicate_type_9 = BaseEventTriggerPredicate.from_dict(_predicate_type_9)

                return predicate_type_9
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_10 = data
                predicate_type_10: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_10, Unset):
                    predicate_type_10 = UNSET
                else:
                    predicate_type_10 = BaseEventTriggerPredicate.from_dict(_predicate_type_10)

                return predicate_type_10
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_11 = data
                predicate_type_11: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_11, Unset):
                    predicate_type_11 = UNSET
                else:
                    predicate_type_11 = BaseEventTriggerPredicate.from_dict(_predicate_type_11)

                return predicate_type_11
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_12 = data
                predicate_type_12: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_12, Unset):
                    predicate_type_12 = UNSET
                else:
                    predicate_type_12 = BaseEventTriggerPredicate.from_dict(_predicate_type_12)

                return predicate_type_12
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_13 = data
                predicate_type_13: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_13, Unset):
                    predicate_type_13 = UNSET
                else:
                    predicate_type_13 = BaseEventTriggerPredicate.from_dict(_predicate_type_13)

                return predicate_type_13
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_14 = data
                predicate_type_14: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_14, Unset):
                    predicate_type_14 = UNSET
                else:
                    predicate_type_14 = BaseEventTriggerPredicate.from_dict(_predicate_type_14)

                return predicate_type_14
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                _predicate_type_15 = data
                predicate_type_15: Union[Unset, BaseEventTriggerPredicate]
                if isinstance(_predicate_type_15, Unset):
                    predicate_type_15 = UNSET
                else:
                    predicate_type_15 = BaseEventTriggerPredicate.from_dict(_predicate_type_15)

                return predicate_type_15
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            _predicate_type_16 = data
            predicate_type_16: Union[Unset, BaseEventTriggerPredicate]
            if isinstance(_predicate_type_16, Unset):
                predicate_type_16 = UNSET
            else:
                predicate_type_16 = BaseEventTriggerPredicate.from_dict(_predicate_type_16)

            return predicate_type_16

        predicate = _parse_predicate(d.pop("predicate", UNSET))

        interval = d.pop("interval", UNSET)

        _severity = d.pop("severity", UNSET)
        severity: Union[Unset, PartialEventTriggerSeverity]
        if isinstance(_severity, Unset):
            severity = UNSET
        else:
            severity = PartialEventTriggerSeverity(_severity)

        enabled = d.pop("enabled", UNSET)

        format_ = d.pop("format", UNSET)

        _triggered_configuration = d.pop("triggeredConfiguration", UNSET)
        triggered_configuration: Union[Unset, None, TriggeredConfiguration]
        if _triggered_configuration is None:
            triggered_configuration = None
        elif isinstance(_triggered_configuration, Unset):
            triggered_configuration = UNSET
        else:
            triggered_configuration = TriggeredConfiguration.from_dict(_triggered_configuration)

        _sms_tags = d.pop("smsTags", UNSET)
        sms_tags: Union[Unset, PartialEventTriggerSmsTags]
        if isinstance(_sms_tags, Unset):
            sms_tags = UNSET
        else:
            sms_tags = PartialEventTriggerSmsTags.from_dict(_sms_tags)

        _device_scope = d.pop("deviceScope", UNSET)
        device_scope: Union[Unset, None, ScopeFilter]
        if _device_scope is None:
            device_scope = None
        elif isinstance(_device_scope, Unset):
            device_scope = UNSET
        else:
            device_scope = ScopeFilter.from_dict(_device_scope)

        commands = []
        _commands = d.pop("commands", UNSET)
        for commands_item_data in _commands or []:
            commands_item = EventTriggerCommand.from_dict(commands_item_data)

            commands.append(commands_item)

        notification_enabled = d.pop("notificationEnabled", UNSET)

        _last_triggered_time = d.pop("lastTriggeredTime", UNSET)
        last_triggered_time: Union[Unset, None, datetime.datetime]
        if _last_triggered_time is None:
            last_triggered_time = None
        elif isinstance(_last_triggered_time, Unset):
            last_triggered_time = UNSET
        else:
            last_triggered_time = isoparse(_last_triggered_time)

        event_trigger_group_id = d.pop("eventTriggerGroupId", UNSET)

        _stateful_trigger_configuration = d.pop("statefulTriggerConfiguration", UNSET)
        stateful_trigger_configuration: Union[Unset, None, StatefulTriggerConfiguration]
        if _stateful_trigger_configuration is None:
            stateful_trigger_configuration = None
        elif isinstance(_stateful_trigger_configuration, Unset):
            stateful_trigger_configuration = UNSET
        else:
            stateful_trigger_configuration = StatefulTriggerConfiguration.from_dict(_stateful_trigger_configuration)

        is_stateful = d.pop("isStateful", UNSET)

        _forwarding_configuration = d.pop("forwardingConfiguration", UNSET)
        forwarding_configuration: Union[Unset, None, ForwardingConfiguration]
        if _forwarding_configuration is None:
            forwarding_configuration = None
        elif isinstance(_forwarding_configuration, Unset):
            forwarding_configuration = UNSET
        else:
            forwarding_configuration = ForwardingConfiguration.from_dict(_forwarding_configuration)

        sets_device_color = d.pop("setsDeviceColor", UNSET)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        _tags = d.pop("tags", UNSET)
        tags: Union[Unset, PartialEventTriggerTags]
        if isinstance(_tags, Unset):
            tags = UNSET
        else:
            tags = PartialEventTriggerTags.from_dict(_tags)

        partial_event_trigger = cls(
            organization_id=organization_id,
            event_type=event_type,
            message=message,
            condition=condition,
            exit_condition=exit_condition,
            predicate=predicate,
            interval=interval,
            severity=severity,
            enabled=enabled,
            format_=format_,
            triggered_configuration=triggered_configuration,
            sms_tags=sms_tags,
            device_scope=device_scope,
            commands=commands,
            notification_enabled=notification_enabled,
            last_triggered_time=last_triggered_time,
            event_trigger_group_id=event_trigger_group_id,
            stateful_trigger_configuration=stateful_trigger_configuration,
            is_stateful=is_stateful,
            forwarding_configuration=forwarding_configuration,
            sets_device_color=sets_device_color,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
            tags=tags,
        )

        partial_event_trigger.additional_properties = d
        return partial_event_trigger

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.tool_description import ToolDescription


T = TypeVar("T", bound="ChatMessageRequest")


@attr.s(auto_attribs=True)
class ChatMessageRequest:
    """
    Attributes:
        message (str):
        default_prompt (str):
        default_model (str):
        tool_choice_prompt (str):
        tool_choice_model (str):
        describe_topic_prompt (str):
        describe_topic_model (str):
        tools (List['ToolDescription']):
        max_tokens (Union[Unset, float]):
        frequency_penalty (Union[Unset, float]):
        presence_penalty (Union[Unset, float]):
        temperature (Union[Unset, float]):
        top_p (Union[Unset, float]):
    """

    message: str
    default_prompt: str
    default_model: str
    tool_choice_prompt: str
    tool_choice_model: str
    describe_topic_prompt: str
    describe_topic_model: str
    tools: List["ToolDescription"]
    max_tokens: Union[Unset, float] = UNSET
    frequency_penalty: Union[Unset, float] = UNSET
    presence_penalty: Union[Unset, float] = UNSET
    temperature: Union[Unset, float] = UNSET
    top_p: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        message = self.message
        default_prompt = self.default_prompt
        default_model = self.default_model
        tool_choice_prompt = self.tool_choice_prompt
        tool_choice_model = self.tool_choice_model
        describe_topic_prompt = self.describe_topic_prompt
        describe_topic_model = self.describe_topic_model
        tools = []
        for tools_item_data in self.tools:
            tools_item = tools_item_data.to_dict()

            tools.append(tools_item)

        max_tokens = self.max_tokens
        frequency_penalty = self.frequency_penalty
        presence_penalty = self.presence_penalty
        temperature = self.temperature
        top_p = self.top_p

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "message": message,
                "defaultPrompt": default_prompt,
                "defaultModel": default_model,
                "toolChoicePrompt": tool_choice_prompt,
                "toolChoiceModel": tool_choice_model,
                "describeTopicPrompt": describe_topic_prompt,
                "describeTopicModel": describe_topic_model,
                "tools": tools,
            }
        )
        if max_tokens is not UNSET:
            field_dict["maxTokens"] = max_tokens
        if frequency_penalty is not UNSET:
            field_dict["frequencyPenalty"] = frequency_penalty
        if presence_penalty is not UNSET:
            field_dict["presencePenalty"] = presence_penalty
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if top_p is not UNSET:
            field_dict["topP"] = top_p

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.tool_description import ToolDescription

        d = src_dict.copy()
        message = d.pop("message")

        default_prompt = d.pop("defaultPrompt")

        default_model = d.pop("defaultModel")

        tool_choice_prompt = d.pop("toolChoicePrompt")

        tool_choice_model = d.pop("toolChoiceModel")

        describe_topic_prompt = d.pop("describeTopicPrompt")

        describe_topic_model = d.pop("describeTopicModel")

        tools = []
        _tools = d.pop("tools")
        for tools_item_data in _tools:
            tools_item = ToolDescription.from_dict(tools_item_data)

            tools.append(tools_item)

        max_tokens = d.pop("maxTokens", UNSET)

        frequency_penalty = d.pop("frequencyPenalty", UNSET)

        presence_penalty = d.pop("presencePenalty", UNSET)

        temperature = d.pop("temperature", UNSET)

        top_p = d.pop("topP", UNSET)

        chat_message_request = cls(
            message=message,
            default_prompt=default_prompt,
            default_model=default_model,
            tool_choice_prompt=tool_choice_prompt,
            tool_choice_model=tool_choice_model,
            describe_topic_prompt=describe_topic_prompt,
            describe_topic_model=describe_topic_model,
            tools=tools,
            max_tokens=max_tokens,
            frequency_penalty=frequency_penalty,
            presence_penalty=presence_penalty,
            temperature=temperature,
            top_p=top_p,
        )

        chat_message_request.additional_properties = d
        return chat_message_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
